summaryrefslogtreecommitdiffstats
path: root/ui/aura/window.cc
diff options
context:
space:
mode:
authorderat@chromium.org <derat@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-11-22 16:55:24 +0000
committerderat@chromium.org <derat@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-11-22 16:55:24 +0000
commit5e4e61f45c2960389b6eeb6bcb061602048ec2db (patch)
tree313a8a75169fcae75d4e2206ada71a3d5807cf75 /ui/aura/window.cc
parent6f682af251936a5b666a69015a746b27a617aac6 (diff)
downloadchromium_src-5e4e61f45c2960389b6eeb6bcb061602048ec2db.zip
chromium_src-5e4e61f45c2960389b6eeb6bcb061602048ec2db.tar.gz
chromium_src-5e4e61f45c2960389b6eeb6bcb061602048ec2db.tar.bz2
s/Move/Stack/ in names of stacking-related methods.
This renames methods in aura::Window, views::Widget, and gfx::Layer. "MoveAbove" becomes "StackAbove" and "MoveToFront" becomes "StackAtTop". BUG=none TEST=built it Review URL: http://codereview.chromium.org/8620002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@111168 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ui/aura/window.cc')
-rw-r--r--ui/aura/window.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/ui/aura/window.cc b/ui/aura/window.cc
index 70040fa..c58205f 100644
--- a/ui/aura/window.cc
+++ b/ui/aura/window.cc
@@ -183,13 +183,13 @@ void Window::SetParent(Window* parent) {
NOTREACHED();
}
-void Window::MoveChildToFront(Window* child) {
+void Window::StackChildAtTop(Window* child) {
if (children_.size() <= 1 || child == children_.back())
return; // In the front already.
- MoveChildAbove(child, children_.back());
+ StackChildAbove(child, children_.back());
}
-void Window::MoveChildAbove(Window* child, Window* other) {
+void Window::StackChildAbove(Window* child, Window* other) {
DCHECK_NE(child, other);
DCHECK(child);
DCHECK(other);
@@ -208,16 +208,16 @@ void Window::MoveChildAbove(Window* child, Window* other) {
children_.insert(children_.begin() + other_i, child);
// Reorder the layer.
- layer()->MoveAbove(child->layer(), other->layer());
+ layer()->StackAbove(child->layer(), other->layer());
- // Move any transient children that share the same parent to be in front of
+ // Stack any transient children that share the same parent to be in front of
// 'child'.
Window* last_transient = child;
for (Windows::iterator i = child->transient_children_.begin();
i != child->transient_children_.end(); ++i) {
Window* transient_child = *i;
if (transient_child->parent_ == this) {
- MoveChildAbove(transient_child, last_transient);
+ StackChildAbove(transient_child, last_transient);
last_transient = transient_child;
}
}